"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.notifyRemotePackumentVersionResolvingFailed = exports.notifyRegistryCallFailedBecauseUnauthorized = exports.notifyRegistryCallFailedBecauseHttp = exports.notifyOfMissingVersion = exports.notifyNoVersions = exports.notifyPackumentNotFoundInAnyRegistry = exports.notifyProjectVersionLoadFailed = exports.notifySemanticallyMalformedProjectVersion = exports.notifySyntacticallyMalformedProjectVersion = exports.suggestFixErrorsInProjectVersionFile = exports.notifyProjectVersionMissing = exports.notifyEnvParsingFailed = exports.notifySyntacticallyMalformedUpmConfig = exports.notifyMissingEnvForUpmConfigPath = exports.notifyChildProcessError = exports.notifyNotUsingWsl = exports.notifyManifestWriteFailed = exports.notifyManifestLoadFailed = exports.notifyManifestLoadFailedBecauseIO = exports.notifySemanticallyMalformedProjectManifest = exports.notifySyntacticallyMalformedProjectManifest = exports.suggestFixErrorsInProjectManifest = exports.notifyManifestMissing = exports.suggestCheckingWorkingDirectory = void 0;
const wsl_1 = require("../io/wsl");
const process_1 = require("../utils/process");
const upm_config_io_1 = require("../io/upm-config-io");
const common_errors_1 = require("../io/common-errors");
const string_parsing_1 = require("../utils/string-parsing");
const common_errors_2 = require("../common-errors");
const packument_1 = require("../domain/packument");
const node_os_1 = require("node:os");
function suggestCheckingWorkingDirectory(log) {
    log.notice("", "Are you in the correct working directory?");
}
exports.suggestCheckingWorkingDirectory = suggestCheckingWorkingDirectory;
function notifyManifestMissing(log, filePath) {
    log.error("", `Could not locate your project manifest at "${filePath}".`);
    suggestCheckingWorkingDirectory(log);
}
exports.notifyManifestMissing = notifyManifestMissing;
function suggestFixErrorsInProjectManifest(log) {
    log.notice("", "Please fix the errors in your project manifest and try again.");
}
exports.suggestFixErrorsInProjectManifest = suggestFixErrorsInProjectManifest;
function notifySyntacticallyMalformedProjectManifest(log) {
    log.error("", "Project manifest file contained json syntax errors.");
    suggestFixErrorsInProjectManifest(log);
}
exports.notifySyntacticallyMalformedProjectManifest = notifySyntacticallyMalformedProjectManifest;
function notifySemanticallyMalformedProjectManifest(log) {
    log.error("", "Project manifest is valid json but was not of the correct shape.");
    suggestFixErrorsInProjectManifest(log);
}
exports.notifySemanticallyMalformedProjectManifest = notifySemanticallyMalformedProjectManifest;
function notifyManifestLoadFailedBecauseIO(log) {
    log.error("", "Could not load project manifest because of a file-system error.");
}
exports.notifyManifestLoadFailedBecauseIO = notifyManifestLoadFailedBecauseIO;
function notifyManifestLoadFailed(log, error) {
    if (error instanceof common_errors_1.FileMissingError)
        notifyManifestMissing(log, error.path);
    else if (error instanceof string_parsing_1.StringFormatError)
        notifySyntacticallyMalformedProjectManifest(log);
    else if (error instanceof common_errors_2.FileParseError)
        notifySemanticallyMalformedProjectManifest(log);
    else if (error instanceof common_errors_1.GenericIOError)
        notifyManifestLoadFailedBecauseIO(log);
}
exports.notifyManifestLoadFailed = notifyManifestLoadFailed;
function notifyManifestWriteFailed(log) {
    log.error("", "Could not save project manifest because of a file-system error.");
}
exports.notifyManifestWriteFailed = notifyManifestWriteFailed;
function notifyNotUsingWsl(log) {
    log.error("", "No wsl detected.");
    log.notice("", "Please make sure you are actually running openupm in wsl.");
}
exports.notifyNotUsingWsl = notifyNotUsingWsl;
function notifyChildProcessError(log) {
    log.error("", "A child process encountered an error.");
}
exports.notifyChildProcessError = notifyChildProcessError;
function notifyMissingEnvForUpmConfigPath(log, variableNames) {
    const nameList = variableNames.map((name) => `"${name}"`).join(", ");
    log.error("", "Could not determine upm-config path because of missing home environment variables.");
    log.notice("", `Please make sure that you set one of the following environment variables: ${nameList}.`);
}
exports.notifyMissingEnvForUpmConfigPath = notifyMissingEnvForUpmConfigPath;
function notifySyntacticallyMalformedUpmConfig(log) {
    log.error("", "Upm-config file contained toml syntax errors.");
    log.notice("", "Please fix the errors in your upm-config and try again.");
}
exports.notifySyntacticallyMalformedUpmConfig = notifySyntacticallyMalformedUpmConfig;
function notifyUpmConfigLoadFailedBecauseIO(log) {
    log.error("", "Could not load upm-config because of a file-system error.");
}
function notifyEnvParsingFailed(log, error) {
    if (error instanceof wsl_1.NoWslError)
        notifyNotUsingWsl(log);
    else if (error instanceof process_1.ChildProcessError)
        notifyChildProcessError(log);
    else if (error instanceof upm_config_io_1.RequiredEnvMissingError)
        notifyMissingEnvForUpmConfigPath(log, error.keyNames);
    else if (error instanceof common_errors_1.GenericIOError)
        notifyUpmConfigLoadFailedBecauseIO(log);
    else if (error instanceof string_parsing_1.StringFormatError)
        notifySyntacticallyMalformedUpmConfig(log);
}
exports.notifyEnvParsingFailed = notifyEnvParsingFailed;
function notifyProjectVersionMissing(log, filePath) {
    log.error("", `Could not locate your projects version file (ProjectVersion.txt) at "${filePath}".`);
    suggestCheckingWorkingDirectory(log);
}
exports.notifyProjectVersionMissing = notifyProjectVersionMissing;
function suggestFixErrorsInProjectVersionFile(log) {
    log.notice("", "Please fix the errors in your project version file and try again.");
}
exports.suggestFixErrorsInProjectVersionFile = suggestFixErrorsInProjectVersionFile;
function notifySyntacticallyMalformedProjectVersion(log) {
    log.error("", "Project version file (ProjectVersion.txt) file contained yaml syntax errors.");
    suggestFixErrorsInProjectVersionFile(log);
}
exports.notifySyntacticallyMalformedProjectVersion = notifySyntacticallyMalformedProjectVersion;
function notifySemanticallyMalformedProjectVersion(log) {
    log.error("", "Project version file (ProjectVersion.txt) file is valid yaml but was not of the correct shape.");
    suggestFixErrorsInProjectVersionFile(log);
}
exports.notifySemanticallyMalformedProjectVersion = notifySemanticallyMalformedProjectVersion;
function notifyProjectVersionLoadFailed(log, error) {
    if (error instanceof common_errors_1.FileMissingError)
        notifyProjectVersionMissing(log, error.path);
    else if (error instanceof common_errors_1.GenericIOError)
        log.error("", "Could not load project version file (ProjectVersion.txt) because of a file-system error.");
    else if (error instanceof string_parsing_1.StringFormatError)
        notifySyntacticallyMalformedProjectVersion(log);
    else if (error instanceof common_errors_2.FileParseError)
        notifySemanticallyMalformedProjectVersion(log);
}
exports.notifyProjectVersionLoadFailed = notifyProjectVersionLoadFailed;
function notifyPackumentNotFoundInAnyRegistry(log, packageName) {
    log.error("", `The package "${packageName}" was not found in any of the provided registries.`);
    log.notice("", "Please make sure you have spelled the name and registry urls correctly.");
}
exports.notifyPackumentNotFoundInAnyRegistry = notifyPackumentNotFoundInAnyRegistry;
function notifyNoVersions(log, packageName) {
    log.error("", `The package ${packageName} has no versions.`);
}
exports.notifyNoVersions = notifyNoVersions;
function notifyOfMissingVersion(log, packageName, requestedVersion, availableVersions) {
    const versionList = availableVersions
        .map((version) => `\t- ${version}`)
        .join(node_os_1.EOL);
    log.error("", `The package "${packageName}" has no published version "${requestedVersion}".`);
    log.notice("", `Maybe you meant one of the following:${node_os_1.EOL}${versionList}`);
}
exports.notifyOfMissingVersion = notifyOfMissingVersion;
function notifyRegistryCallFailedBecauseHttp(log) {
    log.error("", "Could not communicate with registry because of an http error.");
}
exports.notifyRegistryCallFailedBecauseHttp = notifyRegistryCallFailedBecauseHttp;
function notifyRegistryCallFailedBecauseUnauthorized(log) {
    log.error("", "An npm registry rejected your request, because you are unauthorized.");
    log.notice("", "Please make sure you are correctly authenticated for the registry.");
}
exports.notifyRegistryCallFailedBecauseUnauthorized = notifyRegistryCallFailedBecauseUnauthorized;
function notifyRemotePackumentVersionResolvingFailed(log, packageName, error) {
    if (error instanceof common_errors_2.PackumentNotFoundError)
        notifyPackumentNotFoundInAnyRegistry(log, packageName);
    else if (error instanceof packument_1.NoVersionsError)
        notifyNoVersions(log, packageName);
    else if (error instanceof packument_1.VersionNotFoundError)
        notifyOfMissingVersion(log, packageName, error.requestedVersion, error.availableVersions);
    else if (error instanceof common_errors_1.GenericNetworkError)
        notifyRegistryCallFailedBecauseHttp(log);
    else if (error instanceof common_errors_1.RegistryAuthenticationError)
        notifyRegistryCallFailedBecauseUnauthorized(log);
}
exports.notifyRemotePackumentVersionResolvingFailed = notifyRemotePackumentVersionResolvingFailed;
//# sourceMappingURL=error-logging.js.map