"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.RegistryAuthenticationError = exports.GenericNetworkError = exports.FileMissingError = exports.GenericIOError = void 0;
const ts_custom_error_1 = require("ts-custom-error");
/**
 * Generic error for when some non-specific IO operation failed.
 */
class GenericIOError extends ts_custom_error_1.CustomError {
    // noinspection JSUnusedLocalSymbols
    _class = "GenericIOError";
}
exports.GenericIOError = GenericIOError;
/**
 * Error for when a required file or directory is missing.
 */
class FileMissingError extends ts_custom_error_1.CustomError {
    fileName;
    path;
    // noinspection JSUnusedLocalSymbols
    _class = "FileMissingError";
    constructor(
    /**
     * Name of the file. This is a constant string that can be used in
     * ifs and switches to identify the file that was missing.
     */
    fileName, 
    /**
     * The path where the file was searched but not found.
     */
    path) {
        super();
        this.fileName = fileName;
        this.path = path;
    }
}
exports.FileMissingError = FileMissingError;
/**
 * Generic error for when some non-specific network operation failed.
 */
class GenericNetworkError extends ts_custom_error_1.CustomError {
    _class = "GenericNetworkError";
}
exports.GenericNetworkError = GenericNetworkError;
/**
 * Error for when authentication with a registry failed.
 */
class RegistryAuthenticationError extends ts_custom_error_1.CustomError {
    _class = "RegistryAuthenticationError";
    constructor() {
        super();
    }
}
exports.RegistryAuthenticationError = RegistryAuthenticationError;
//# sourceMappingURL=common-errors.js.map